$OpenBSD: patch-src_cd-profile_c,v 1.11 2013/11/11 15:52:40 ajacoutot Exp $

/var/lib -> /var/db

--- src/cd-profile.c.orig	Wed Oct 30 15:25:28 2013
+++ src/cd-profile.c	Mon Nov 11 16:49:46 2013
@@ -404,7 +404,7 @@ cd_profile_install_system_wide (CdProfile *profile, GE
 		goto out;
 	}
 
-	/* is profile already installed in /var/lib/color */
+	/* is profile already installed in /var/db/color */
 	if (g_str_has_prefix (priv->filename,
 			      CD_SYSTEM_PROFILES_DIR)) {
 		ret = FALSE;
@@ -416,7 +416,7 @@ cd_profile_install_system_wide (CdProfile *profile, GE
 		goto out;
 	}
 
 	/* is profile already installed in /usr/share/color */
 	if (g_str_has_prefix (priv->filename,
 			      DATADIR "/color")) {
 		ret = FALSE;
@@ -1094,7 +1094,7 @@ cd_profile_set_filename (CdProfile *profile,
 	}
 
 	/* find out if we have a GResource copy */
-	if (g_str_has_prefix (filename, "/usr/share/color/icc/colord/")) {
+	if (g_str_has_prefix (filename, "${LOCALBASE}/share/color/icc/colord/")) {
 		data = g_build_filename ("/org/freedesktop/colord",
 					 "profiles",
 					 filename + 28,
@@ -416,7 +416,7 @@ cd_profile_install_system_wide (CdProfile *profile, GE
 	}
 
-	/* is profile already installed in /usr/share/color */
+	/* is profile already installed in ${LOCALBASE}/share/color */
 	if (g_str_has_prefix (priv->filename,
 			      DATADIR "/color")) {
